Security Advisories (3)
CPANSA-Jifty-2011-01 (2011-03-17)

The path as passed in the fragment request data structure was used verbatim in the dispatcher and other locations. This possibly allowed requests to walk around ACLs by requesting '/some/safe/place/../../../dangerous' as a fragment.

CPANSA-Jifty-2009-01 (2009-04-09)

The REST plugin would let you call any method on the model.

CPANSA-Jifty-2008-01 (2009-04-08)

Allowed all actions on GET.

NAME

Jifty::Server - Standalone web server for Jifty applications

SYNOPSIS

use Jifty::Server;
my $server = Jifty::Server->new();
$server->run();

DESCRIPTION

Jifty::Server is a subclass of HTTP::Server::Simple which creates a handy standalone web server for a lightweight Jifty application.

METHODS

new

Creates a new Jifty::Server object.

setup_jifty

Sets up the Jifty singleton. This is called automatically by "new".

handle_request

Overrives HTML::Server::Simple::Mason's handle_request method to make use of Module::Refresh to refresh any relevant modules, as well as to set up the $JiftyWeb global before handling the actual request.

Overrives HTML::Server::Simple::Mason's print_banner to use the logging framework to record the server's startup

recorder_prefix

Returns the filename prefix used if HTTP::Server::Simple::Recorder support is being used.

recording_on

Sets this server to use HTTP::Server::Simple::Recorder.

(See also the JIFTY_RECORD environment variable and the -r switch to standalone_server.)

after_setup_listener

If $ENV{JIFTY_SERVER_SIGREADY} is set, send the signal to the parent when the server is ready for requests.